dag_cbor.decoding
=================

.. automodule:: dag_cbor.decoding

DecodeCallback
--------------

.. autodata:: dag_cbor.decoding.DecodeCallback

decode
------

.. autofunction:: dag_cbor.decoding.decode
